pub async fn parse_unit_state(
config: &Config,
connection: &Connection,
) -> Result<SystemdUnitStats, MonitordUnitsError>Expand description
Pull all units from dbus and count how system is setup and behaving
pub async fn parse_unit_state(
config: &Config,
connection: &Connection,
) -> Result<SystemdUnitStats, MonitordUnitsError>Pull all units from dbus and count how system is setup and behaving