pub struct ServiceStats {Show 16 fields
pub active_enter_timestamp: u64,
pub active_exit_timestamp: u64,
pub cpuusage_nsec: u64,
pub inactive_exit_timestamp: u64,
pub ioread_bytes: u64,
pub ioread_operations: u64,
pub memory_available: u64,
pub memory_current: u64,
pub nrestarts: u32,
pub processes: u32,
pub restart_usec: u64,
pub state_change_timestamp: u64,
pub status_errno: i32,
pub tasks_current: u64,
pub timeout_clean_usec: u64,
pub watchdog_usec: u64,
}Expand description
Per-service metrics from the org.freedesktop.systemd1.Service and Unit D-Bus interfaces. Ref: https://www.freedesktop.org/software/systemd/man/org.freedesktop.systemd1.html
Fields
active_enter_timestamp: u64Realtime timestamp (usec since epoch) when the unit most recently entered the active state
active_exit_timestamp: u64Realtime timestamp (usec since epoch) when the unit most recently left the active state
cpuusage_nsec: u64Total CPU time consumed by this service’s cgroup in nanoseconds
inactive_exit_timestamp: u64Realtime timestamp (usec since epoch) when the unit most recently left the inactive state
ioread_bytes: u64Total bytes read from block I/O by this service’s cgroup
ioread_operations: u64Total number of block I/O read operations by this service’s cgroup
memory_available: u64Memory available to the service (MemoryAvailable from cgroup), in bytes
memory_current: u64Current memory usage of the service’s cgroup in bytes
nrestarts: u32Number of times systemd has restarted this service (automatic restarts)
processes: u32Current number of processes in this service’s cgroup
restart_usec: u64Configured restart delay for this service in microseconds (RestartUSec)
state_change_timestamp: u64Realtime timestamp (usec since epoch) of the most recent state change of any kind
status_errno: i32errno-style exit status code from the main process (0 = success)
tasks_current: u64Current number of tasks (threads) in this service’s cgroup
timeout_clean_usec: u64Timeout in microseconds for the cleanup of resources after the service exits
watchdog_usec: u64Watchdog timeout in microseconds; the service must ping within this interval or be killed